@@ -1468,7 +1468,7 @@ def killFlash(restoreSaved=True):
     global viewport
     if _flashEventSourceId:
         if _flashEventSourceId > 0:
-            GObject.source_remove(_flashEventSourceId)
+            GLib.source_remove(_flashEventSourceId)
         if restoreSaved:
             (_lines, _regionWithFocus, viewport, flashTime) = _saved
             refresh(panToCursor=False, stopFlash=False)
@@ -1477,7 +1477,7 @@ def killFlash(restoreSaved=True):
 def resetFlashTimer():
     global _flashEventSourceId
     if _flashEventSourceId > 0:
-        GObject.source_remove(_flashEventSourceId)
+        GLib.source_remove(_flashEventSourceId)
         flashTime = _saved[3]
         _flashEventSourceId = GLib.timeout_add(flashTime, _flashCallback)
 
@@ -1498,7 +1498,7 @@ def _initFlash(flashTime):
 
     if _flashEventSourceId:
         if _flashEventSourceId > 0:
-            GObject.source_remove(_flashEventSourceId)
+            GLib.source_remove(_flashEventSourceId)
         _flashEventSourceId = 0
     else:
         _saved = (_lines, _regionWithFocus, viewport, flashTime)
@@ -1843,7 +1843,7 @@ def shutdown():
 
     if _brlAPIRunning:
         _brlAPIRunning = False
-        GObject.source_remove(_brlAPISourceId)
+        GLib.source_remove(_brlAPISourceId)
         _brlAPISourceId = 0
         try:
             _brlAPI.leaveTtyMode()
