@@ -147,7 +147,7 @@ class Script(default.Script):
                 if mode == pyatspi.TEXT_BOUNDARY_LINE_START or \
                    len(mystr) == 0 or mystr[len(mystr)-1] in '.?!':
                     string = self.utilities.adjustForRepeats(string)
-                    if string.decode("UTF-8").isupper():
+                    if string.isupper():
                         voice = settings.voices[settings.UPPERCASE_VOICE]
                     else:
                         voice = settings.voices[settings.DEFAULT_VOICE]
@@ -185,7 +185,7 @@ class Script(default.Script):
         #
         if len(string) != 0:
             string = self.utilities.adjustForRepeats(string)
-            if string.decode("UTF-8").isupper():
+            if string.isupper():
                 voice = settings.voices[settings.UPPERCASE_VOICE]
             else:
                 voice = settings.voices[settings.DEFAULT_VOICE]
