@@ -71,8 +71,6 @@ userCustomizableSettings = [
     "brailleAlignmentStyle",
     "enableBrailleMonitor",
     "verbalizePunctuationStyle",
-    "showMainWindow",
-    "quitOrcaNoConfirmation",
     "presentToolTips",
     "sayAllStyle",
     "keyboardLayout",
@@ -212,6 +210,13 @@ SAYALL_STYLE_LINE     = 0
 SAYALL_STYLE_SENTENCE = 1
 sayAllStyle = SAYALL_STYLE_SENTENCE
 
+# Speech Dispatcher capitalization styles.
+CAPITALIZATION_STYLE_NONE  = "none"
+CAPITALIZATION_STYLE_SPELL = "spell"
+CAPITALIZATION_STYLE_ICON = "icon"
+capitalizationStyle = CAPITALIZATION_STYLE_NONE
+
+
 # The absolue amount to change the speech rate when
 # increasing or decreasing speech.  This is a numerical
 # value that represents an ACSS rate value.
@@ -260,7 +265,7 @@ voicesKeys = {
 
 voices = {
     DEFAULT_VOICE: ACSS({}),
-    UPPERCASE_VOICE: ACSS({ACSS.AVERAGE_PITCH : 5.6}),
+    UPPERCASE_VOICE: ACSS({ACSS.AVERAGE_PITCH : 7.0}),
     HYPERLINK_VOICE: ACSS({}),
     SYSTEM_VOICE: ACSS({}),
 }
@@ -363,19 +368,6 @@ enableMnemonicSpeaking = False
 #
 enablePositionSpeaking = False
 
-# If True, show the main Orca window.
-#
-showMainWindow          = True
-
-# If True, show the splash window.
-#
-showSplashWindow          = True
-
-# If True, quit Orca without confirmation when the user presses
-# <Orca-modifier>-q.
-#
-quitOrcaNoConfirmation  = False
-
 # If True, always present locking key state changes; if False, never present
 # locking key state changes. If None, make the decision based on Orca's normal
 # behavior.
